namespace elm { namespace interface { namespace atspi { 
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<Eina_Unicode>::type Text::character_get( ::efl::eolian::in_traits<int>::type offset) const
{
   Eina_Unicode __return_value =  ::elm_interface_atspi_text_character_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(offset));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Unicode>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<int>::type Text::caret_offset_get() const
{
   int __return_value =  ::elm_interface_atspi_text_caret_offset_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Text::caret_offset_set( ::efl::eolian::in_traits<int>::type offset) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_caret_offset_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(offset));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Text::character_extents_get( ::efl::eolian::in_traits<int>::type offset,  ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::out_traits<Eina_Rectangle>::type rect) const
{
   Eina_Rectangle __out_param_rect = {};
   Eina_Bool __return_value =  ::elm_interface_atspi_text_character_extents_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(offset)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      , & __out_param_rect);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Eina_Rectangle>::type, Eina_Rectangle>(rect, __out_param_rect);
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<int>::type Text::character_count_get() const
{
   int __return_value =  ::elm_interface_atspi_text_character_count_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<int>::type Text::offset_at_point_get( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y) const
{
   int __return_value =  ::elm_interface_atspi_text_offset_at_point_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Text::range_extents_get( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::in_traits<int>::type start_offset,  ::efl::eolian::in_traits<int>::type end_offset,  ::efl::eolian::out_traits<Eina_Rectangle>::type rect) const
{
   Eina_Rectangle __out_param_rect = {};
   Eina_Bool __return_value =  ::elm_interface_atspi_text_range_extents_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(start_offset)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(end_offset)
      , & __out_param_rect);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Eina_Rectangle>::type, Eina_Rectangle>(rect, __out_param_rect);
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<int>::type Text::selections_count_get() const
{
   int __return_value =  ::elm_interface_atspi_text_selections_count_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<void>::type Text::selection_get( ::efl::eolian::in_traits<int>::type selection_number,  ::efl::eolian::out_traits<int>::type start_offset,  ::efl::eolian::out_traits<int>::type end_offset) const
{
   int __out_param_start_offset = {};
   int __out_param_end_offset = {};
    ::elm_interface_atspi_text_selection_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(selection_number)
      , & __out_param_start_offset
      , & __out_param_end_offset);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(start_offset, __out_param_start_offset);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(end_offset, __out_param_end_offset);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Text::selection_set( ::efl::eolian::in_traits<int>::type selection_number,  ::efl::eolian::in_traits<int>::type start_offset,  ::efl::eolian::in_traits<int>::type end_offset) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_selection_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(selection_number)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(start_offset)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(end_offset));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Text::selection_add( ::efl::eolian::in_traits<int>::type start_offset,  ::efl::eolian::in_traits<int>::type end_offset) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_selection_add(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(start_offset)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(end_offset));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Text::selection_remove( ::efl::eolian::in_traits<int>::type selection_number) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_selection_remove(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(selection_number));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
} } } 
namespace eo_cxx {
namespace elm { namespace interface { namespace atspi { 
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<Eina_Unicode>::type Text::character_get( ::efl::eolian::in_traits<int>::type offset) const
{
   Eina_Unicode __return_value =  ::elm_interface_atspi_text_character_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(offset));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Unicode>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<int>::type Text::caret_offset_get() const
{
   int __return_value =  ::elm_interface_atspi_text_caret_offset_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Text::caret_offset_set( ::efl::eolian::in_traits<int>::type offset) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_caret_offset_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(offset));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Text::character_extents_get( ::efl::eolian::in_traits<int>::type offset,  ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::out_traits<Eina_Rectangle>::type rect) const
{
   Eina_Rectangle __out_param_rect = {};
   Eina_Bool __return_value =  ::elm_interface_atspi_text_character_extents_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(offset)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      , & __out_param_rect);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Eina_Rectangle>::type, Eina_Rectangle>(rect, __out_param_rect);
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<int>::type Text::character_count_get() const
{
   int __return_value =  ::elm_interface_atspi_text_character_count_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<int>::type Text::offset_at_point_get( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::in_traits<int>::type x,  ::efl::eolian::in_traits<int>::type y) const
{
   int __return_value =  ::elm_interface_atspi_text_offset_at_point_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(x)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(y));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Text::range_extents_get( ::efl::eolian::in_traits<bool>::type screen_coords,  ::efl::eolian::in_traits<int>::type start_offset,  ::efl::eolian::in_traits<int>::type end_offset,  ::efl::eolian::out_traits<Eina_Rectangle>::type rect) const
{
   Eina_Rectangle __out_param_rect = {};
   Eina_Bool __return_value =  ::elm_interface_atspi_text_range_extents_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(screen_coords)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(start_offset)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(end_offset)
      , & __out_param_rect);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Eina_Rectangle>::type, Eina_Rectangle>(rect, __out_param_rect);
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<int>::type Text::selections_count_get() const
{
   int __return_value =  ::elm_interface_atspi_text_selections_count_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<void>::type Text::selection_get( ::efl::eolian::in_traits<int>::type selection_number,  ::efl::eolian::out_traits<int>::type start_offset,  ::efl::eolian::out_traits<int>::type end_offset) const
{
   int __out_param_start_offset = {};
   int __out_param_end_offset = {};
    ::elm_interface_atspi_text_selection_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(selection_number)
      , & __out_param_start_offset
      , & __out_param_end_offset);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(start_offset, __out_param_start_offset);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<int>::type, int>(end_offset, __out_param_end_offset);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Text::selection_set( ::efl::eolian::in_traits<int>::type selection_number,  ::efl::eolian::in_traits<int>::type start_offset,  ::efl::eolian::in_traits<int>::type end_offset) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_selection_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(selection_number)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(start_offset)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(end_offset));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Text::selection_add( ::efl::eolian::in_traits<int>::type start_offset,  ::efl::eolian::in_traits<int>::type end_offset) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_selection_add(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(start_offset)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(end_offset));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_TEXT_INTERFACE_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Text::selection_remove( ::efl::eolian::in_traits<int>::type selection_number) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_text_selection_remove(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(selection_number));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
inline elm::interface::atspi::Text::operator ::elm::interface::atspi::Text() const { return *static_cast< ::elm::interface::atspi::Text const*>(static_cast<void const*>(this)); }
inline elm::interface::atspi::Text::operator ::elm::interface::atspi::Text&() { return *static_cast< ::elm::interface::atspi::Text*>(static_cast<void*>(this)); }
inline elm::interface::atspi::Text::operator ::elm::interface::atspi::Text const&() const { return *static_cast< ::elm::interface::atspi::Text const*>(static_cast<void const*>(this)); }
} } } }

